@@ -21,9 +21,8 @@
  */
 
 #include "rcs.h"
-RCS_ID("$Id: ansi.c,v 1.16 1993/08/05 14:23:28 mlschroe Exp $ FAU")
+RCS_ID("$Id: ansi.c,v 1.18 1993/08/10 11:04:04 jnweiger Exp $ FAU")
 
-#include <stdio.h>
 #include <sys/types.h>
 #include <fcntl.h>
 #ifndef sun	/* we want to know about TIOCPKT. */
@@ -567,10 +566,14 @@ skip:	      if (--len == 0)
 		  break;
 		}
 	      break;
+	    case '\033':
+	      SaveChar('\033');
+	      break;
 	    default:
 	      curr->w_state = ASTR;
 	      SaveChar('\033');
 	      SaveChar(c);
+	      break;
 	    }
 	  break;
 	case ASTR:
@@ -1112,9 +1115,9 @@ int c, intermediate;
 	    {
 	    case 1:
 	      CursorkeysMode(curr->w_cursorkeys = i);
-    #ifndef TIOCPKT
+#ifndef TIOCPKT
 	      NewAutoFlow(curr, !i);
-    #endif /* !TIOCPKT */
+#endif /* !TIOCPKT */
 	      break;
 	    case 3:
 	      i = (i ? Z0width : Z1width);
