@@ -27,11 +27,11 @@ RCS_ID("$Id: attacher.c,v 1.5 1993/08/03 22:22:37 jnweiger Exp $ FAU")
 #include <sys/stat.h>
 #include <fcntl.h>
 #include <signal.h>
-#include <pwd.h>
 #include "config.h"
 #include "screen.h"
 #include "extern.h"
 
+#include <pwd.h>
 #ifdef SHADOWPW
 # include <shadow.h>
 #endif /* SHADOWPW */
@@ -734,7 +734,7 @@ screen_builtin_lck()
   char fullname[100], *cp1, message[BUFSIZ];
   char c, *pass, mypass[9];
 #ifdef SHADOWPW
-  struct spwd *sss = NULL;
+  static struct spwd *sss;
 #endif
   int t;
 
@@ -770,8 +770,9 @@ realpw:
     {
       debug("builtin_lock: ppp->pw_passwd bad, has it a shadow?\n");
 #ifdef SHADOWPW
-      setspent(); /* rewind shadow file */
-      if ((sss == NULL) && (sss = getspnam(ppp->pw_name)))
+      if (sss == 0)
+        sss = getspnam(ppp->pw_name);
+      if (sss && pass != sss->sp_pwdp)
         {
           pass = sss->sp_pwdp;
           goto realpw;
