@@ -21,7 +21,7 @@
  */
 
 #include "rcs.h"
-RCS_ID("$Id: comm.c,v 1.4 1993/07/21 15:42:50 mlschroe Exp $ FAU")
+RCS_ID("$Id: comm.c,v 1.8 1993/08/05 14:23:32 mlschroe Exp $ FAU")
 
 #include "config.h"
 #include "acl.h"
@@ -33,13 +33,14 @@ struct comm comms[RC_LAST + 1] =
 {
 #ifdef MULTIUSER
   { "acladd",		ARGS_ONE },
-  { "aclchg",		ARGS_TWO },
+  { "aclchg",		ARGS_THREE },
   { "acldel",		ARGS_ONE },
   { "aclgrp",		ARGS_ONE },
 #endif
   { "activity",		ARGS_ONE },
-  { "aka",		NEED_FORE|ARGS_ZEROONE },
+  { "aka",		NEED_FORE|ARGS_ZEROONE },	/* TO BE REMOVED */
   { "allpartial",	ARGS_ONE },
+  { "at",		ARGS_TWO|ARGS_ORMORE },
   { "autodetach",	ARGS_ONE },
 #ifdef AUTO_NUKE
   { "autonuke",		NEED_DISPLAY|ARGS_ONE },
@@ -62,11 +63,12 @@ struct comm comms[RC_LAST + 1] =
   { "copy_reg",		ARGS_ZEROONE },
   { "crlf",		ARGS_ONE },
 #endif
+  { "debug",		ARGS_ZEROONE },
 #ifdef AUTO_NUKE
   { "defautonuke",	ARGS_ONE },
 #endif
   { "defflow",		ARGS_ONETWO },
-#ifdef UTMPOK
+#if defined(UTMPOK) && defined(LOGOUTOK)
   { "deflogin",		ARGS_ONE },
 #endif
   { "defmode",		ARGS_ONE },
@@ -77,6 +79,7 @@ struct comm comms[RC_LAST + 1] =
 #endif
   { "defwrap",		ARGS_ONE },
   { "detach",		NEED_DISPLAY|ARGS_ZERO },
+  { "displays",		NEED_DISPLAY|ARGS_ZERO },
   { "dumptermcap",	ARGS_ZERO },
   { "duplicate",	ARGS_ZERO|ARGS_ORMORE },
   { "echo",		ARGS_ONETWO },
@@ -106,7 +109,7 @@ struct comm comms[RC_LAST + 1] =
 #endif
   { "log",		ARGS_ZEROONE },
   { "logdir",		ARGS_ONE },
-#ifdef UTMPOK
+#if defined(UTMPOK) && defined(LOGOUTOK)
   { "login",		NEED_FORE|ARGS_ZEROONE },
 #endif
 #ifdef COPY_PASTE
@@ -131,7 +134,7 @@ struct comm comms[RC_LAST + 1] =
   { "password",		ARGS_ZEROONE },
 #endif
 #ifdef COPY_PASTE
-  { "paste",		NEED_DISPLAY|ARGS_ZERO },
+  { "paste",		NEED_DISPLAY|ARGS_ZEROONE },
 #endif
   { "pow_break",	NEED_FORE|ARGS_ZEROONE },
 #ifdef POW_DETACH
@@ -156,9 +159,10 @@ struct comm comms[RC_LAST + 1] =
 #endif
   { "select",		ARGS_ZEROONE },
   { "sessionname",	ARGS_ZEROONE },
-  { "setenv",		ARGS_TWO },
+  { "setenv",		ARGS_ZEROONETWO },
   { "shell",		ARGS_ONE },
-  { "shellaka",		ARGS_ONE },
+  { "shellaka",		ARGS_ONE },			/* TO BE REMOVED */
+  { "shelltitle",	ARGS_ONE },
   { "silence",		NEED_FORE|ARGS_ZEROONE },
   { "silencewait",	ARGS_ONE },
   { "sleep",		ARGS_ONE },
@@ -171,11 +175,13 @@ struct comm comms[RC_LAST + 1] =
   { "termcap",		ARGS_TWOTHREE },
   { "terminfo",		ARGS_TWOTHREE },
   { "time",		ARGS_ZERO },
+  { "title",		NEED_FORE|ARGS_ZEROONE },
   { "unsetenv",		ARGS_ONE },
   { "vbell",		ARGS_ZEROONE },
   { "vbell_msg",	ARGS_ONE },
   { "vbellwait",	ARGS_ONE },
   { "version",		ARGS_ZERO },
+  { "wall",		NEED_DISPLAY|ARGS_ONE|ARGS_ORMORE },
   { "width",		NEED_DISPLAY|ARGS_ZEROONE },
   { "windows",		ARGS_ZERO },
   { "wrap",		NEED_FORE|ARGS_ZEROONE },
@@ -184,5 +190,6 @@ struct comm comms[RC_LAST + 1] =
 #endif
   { "writelock",	NEED_FORE|ARGS_ZEROONE },
   { "xoff",		NEED_DISPLAY|ARGS_ZERO },
-  { "xon",		NEED_DISPLAY|ARGS_ZERO }
+  { "xon",		NEED_DISPLAY|ARGS_ZERO },
+  { "zombie",		ARGS_ZEROONE }
 };
