@@ -21,7 +21,7 @@
  */
 
 #include "rcs.h"
-RCS_ID("$Id: display.c,v 1.8 1993/07/21 15:43:02 mlschroe Exp $ FAU")
+RCS_ID("$Id: display.c,v 1.11 1993/08/04 00:42:31 mlschroe Exp $ FAU")
 
 
 #include <sys/types.h>
@@ -36,8 +36,6 @@ static void PutChar __P((int));
 static int  BlankResize __P((int, int));
 
 
-extern char *tgoto __P((char *, int, int));
-
 extern struct win *windows;
 
 extern int  use_hardstatus;
@@ -230,10 +228,6 @@ FreeDisplay()
   ASSERT(d);
   if (d_status_lastmsg)
     free(d_status_lastmsg);
-# ifdef COPY_PASTE
-  if (d_copybuffer)
-    free(d_copybuffer);
-# endif
   if (d_obuf)
     free(d_obuf);
   *dp = display->_d_next;
@@ -517,8 +511,8 @@ int x2, y2;
     {
       return;
     }
-  if (!MS && d_attr)	/* Safe to move in SO mode ? */
-    SetAttr(0);
+  if (!MS && (d_attr || d_font != ASCII))	/* Safe to move ? */
+    SetAttrFont(0, ASCII);
   if (y1 < 0			/* don't know the y position */
       || (y2 > d_bot && y1 <= d_bot)	/* have to cross border */
       || (y2 < d_top && y1 >= d_top))	/* of scrollregion ?    */
