@@ -18,7 +18,7 @@
  * Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
  ****************************************************************
- * $Id: display.h,v 1.3 1993/07/21 15:43:05 mlschroe Exp $ FAU
+ * $Id: display.h,v 1.4 1993/07/30 01:24:33 jnweiger Exp $ FAU
  */
 
 struct win;			/* forward declaration */
@@ -69,10 +69,6 @@ struct display
   int   _d_obuffree;		/* free bytes in buffer */
 #ifdef AUTO_NUKE
   int	_d_auto_nuke;		/* autonuke flag */
-#endif
-#ifdef COPY_PASTE
-  char	*_d_copybuffer;
-  int	_d_copylen;
 #endif
   union	tcu _d_tcs[T_N];	/* terminal capabilities */
   char	*_d_attrtab[NATTR];
@@ -143,8 +139,6 @@ extern struct display TheDisplay;
 #define d_obufp		DISPLAY(_d_obufp)
 #define d_obuffree	DISPLAY(_d_obuffree)
 #define d_auto_nuke	DISPLAY(_d_auto_nuke)
-#define d_copybuffer	DISPLAY(_d_copybuffer)
-#define d_copylen	DISPLAY(_d_copylen)
 #define d_tcs		DISPLAY(_d_tcs)
 #define d_attrtab	DISPLAY(_d_attrtab)
 #define d_dospeed	DISPLAY(_d_dospeed)
