@@ -18,7 +18,7 @@
  * Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
  ****************************************************************
- * $Id: extern.h,v 1.13 1993/08/04 00:42:34 mlschroe Exp $ FAU
+ * $Id: extern.h,v 1.14 1993/08/16 14:49:04 mlschroe Exp $ FAU
  */
 
 
@@ -245,9 +245,9 @@ extern char *SaveStr __P((const char *));
 extern void  centerline __P((char *));
 extern char *Filename __P((char *));
 extern char *stripdev __P((char *));
-#if !defined(MEMFUNCS_DECLARED) && !defined(bcopy)
+#if defined(NEED_OWN_BCOPY) && !defined(linux)
 extern void  bcopy __P((char *, char *, int));
-#endif /* !MEMFUNCS_DECLARED && !bcopy */
+#endif
 extern void  bclear __P((char *, int));
 extern void  closeallfiles __P((int));
 extern int   UserContext __P((void));
