@@ -21,10 +21,13 @@
  */
 
 #include "rcs.h"
-RCS_ID("$Id: loadav.c,v 1.1.1.1 1993/06/16 23:51:13 jnweiger Exp $ FAU")
+RCS_ID("$Id: loadav.c,v 1.2 1993/08/16 14:49:07 mlschroe Exp $ FAU")
 
 #include <sys/types.h>
 #include <fcntl.h>
+#ifdef ultrix
+# include <sys/fixpoint.h>
+#endif /* ultrix */
 
 #include "config.h"
 #include "screen.h"
@@ -203,6 +206,9 @@ GetLoadav()
 
 /***************************************************************/
 
+#ifndef FIX_TO_DBL
+#define FIX_TO_DBL(l) ((double)(l) /  LOADAV_SCALE)
+#endif
 
 void
 AddLoadav(p)
@@ -214,7 +220,7 @@ char *p;
   j = GetLoadav();
   for (i = 0; i < j; i++)
     {
-      sprintf(p, " %2.2f", (double)loadav[i] / LOADAV_SCALE);
+      sprintf(p, " %2.2f", FIX_TO_DBL(loadav[i]));
       p += strlen(p);
     }
 }
