@@ -21,7 +21,7 @@
  */
 
 #include "rcs.h"
-RCS_ID("$Id: mark.c,v 1.2 1993/07/21 15:43:11 mlschroe Exp $ FAU")
+RCS_ID("$Id: mark.c,v 1.4 1993/07/30 01:24:47 jnweiger Exp $ FAU")
 
 #include <sys/types.h>
 
@@ -50,7 +50,6 @@ static void MarkSetCursor __P((void));
 extern struct win *fore;
 extern struct display *display;
 extern char *null, *blank;
-extern char Esc, MetaEsc;
 
 #ifdef NETHACK
 extern nethackflag;
@@ -296,7 +295,7 @@ int a, b;
 
 
 int
-GetHistory()	/* return value 1 if d_copybuffer changed */
+GetHistory()	/* return value 1 if u_copybuffer changed */
 {
   int i = 0, q = 0, xx, yy, x, y;
   char *linep;
@@ -324,15 +323,15 @@ GetHistory()	/* return value 1 if d_copybuffer changed */
     }
   if (yy < 0)
     return 0;
-  if (d_copybuffer != NULL)
-    free(d_copybuffer);
-  if ((d_copybuffer = malloc((unsigned) (i - x + 2))) == NULL)
+  if (d_user->u_copybuffer != NULL)
+    UserFreeCopyBuffer(d_user);
+  if ((d_user->u_copybuffer = malloc((unsigned) (i - x + 2))) == NULL)
     {
       Msg(0, "Not enough memory... Sorry.");
       return 0;
     }
-  bcopy(linep - i + x + 1, d_copybuffer, i - x + 1);
-  d_copylen = i - x + 1;
+  bcopy(linep - i + x + 1, d_user->u_copybuffer, i - x + 1);
+  d_user->u_copylen = i - x + 1;
   return 1;
 }
 
@@ -750,30 +749,28 @@ int *inlenp;
 	      x2 = cx;
 	      y2 = cy;
 	      newcopylen = rem(markdata->x1, markdata->y1, x2, y2, 2, (char *)0, 0); /* count */
-	      if (d_copybuffer != NULL && !append_mode)
+	      if (d_user->u_copybuffer != NULL && !append_mode)
 		{
-		  d_copylen = 0;
-		  free(d_copybuffer);
-		  d_copybuffer = NULL;
+		  UserFreeCopyBuffer(d_user);
 		}
 	      if (newcopylen > 0)
 		{
 		  /* the +3 below is for : cr + lf + \0 */
-		  if (d_copybuffer != NULL)
-		    d_copybuffer = realloc(d_copybuffer,
-			(unsigned) (d_copylen + newcopylen + 3));
+		  if (d_user->u_copybuffer != NULL)
+		    d_user->u_copybuffer = realloc(d_user->u_copybuffer,
+			(unsigned) (d_user->u_copylen + newcopylen + 3));
 		  else
 		    {
-		    d_copylen = 0;
-		    d_copybuffer = malloc((unsigned) (newcopylen + 3));
+		      d_user->u_copylen = 0;
+		      d_user->u_copybuffer = malloc((unsigned) (newcopylen + 3));
 		    }
-		  if (d_copybuffer == NULL)
+		  if (d_user->u_copybuffer == NULL)
 		    {
 		      MarkAbort();
 		      in_mark = 0;
 		      Msg(0, "Not enough memory... Sorry.");
-		      d_copylen = 0;
-		      d_copybuffer = NULL;
+		      d_user->u_copylen = 0;
+		      d_user->u_copybuffer = NULL;
 		      break;
 		    }
 		  if (append_mode)
@@ -786,17 +783,17 @@ int *inlenp;
 			case 0:
 			  if (join_with_cr)
 			    {
-			      d_copybuffer[d_copylen] = '\r';
-			      d_copylen++;
+			      d_user->u_copybuffer[d_user->u_copylen] = '\r';
+			      d_user->u_copylen++;
 			    }
-			  d_copybuffer[d_copylen] = '\n';
-			  d_copylen++;
+			  d_user->u_copybuffer[d_user->u_copylen] = '\n';
+			  d_user->u_copylen++;
 			  break;
 			case 1:
 			  break;
 			case 2:
-			  d_copybuffer[d_copylen] = ' ';
-			  d_copylen++;
+			  d_user->u_copybuffer[d_user->u_copylen] = ' ';
+			  d_user->u_copylen++;
 			  break;
 			}
 		    }
@@ -806,7 +803,9 @@ int *inlenp;
 		      markdata->second = 0;
 		      yend -= MarkScrollUpDisplay(fore->w_histheight - markdata->hist_offset);
 		    }
-		  d_copylen += rem(markdata->x1, markdata->y1, x2, y2, markdata->hist_offset == fore->w_histheight, d_copybuffer + d_copylen, yend);
+		  d_user->u_copylen += rem(markdata->x1, markdata->y1, x2, y2, 
+		    markdata->hist_offset == fore->w_histheight, 
+		    d_user->u_copybuffer + d_user->u_copylen, yend);
 		}
 	      if (markdata->hist_offset != fore->w_histheight)
 		LAY_CALL_UP(Activate(0));
@@ -815,7 +814,7 @@ int *inlenp;
 		Msg(0, "Appended %d characters to buffer",
 		    newcopylen);
 	      else
-		Msg(0, "Copied %d characters into buffer", d_copylen);
+		Msg(0, "Copied %d characters into buffer", d_user->u_copylen);
 	      if (write_buffer)
 		WriteFile(DUMP_EXCHANGE);
 	      in_mark = 0;
