@@ -18,7 +18,7 @@
  * Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
  ****************************************************************
- * $Id: os.h,v 1.4 1993/08/05 14:23:53 mlschroe Exp $ FAU
+ * $Id: os.h,v 1.6 1993/08/16 14:49:09 mlschroe Exp $ FAU
  */
 
 #include <stdio.h>
@@ -355,7 +355,7 @@ typedef int uid_t;
  * tschmidt@vax.micron.com
  */
 #ifndef FD_SET
-# ifdef SUNOS3
+# ifndef SUNOS3
 typedef struct fd_set
 {
   int fds_bits[1];
