@@ -21,16 +21,12 @@
  */
 
 #include "rcs.h"
-RCS_ID("$Id: process.c,v 1.18 1993/08/05 14:24:01 mlschroe Exp $ FAU")
+RCS_ID("$Id: process.c,v 1.21 1993/08/16 14:49:16 mlschroe Exp $ FAU")
 
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <signal.h>
 #include <fcntl.h>
-#if !defined(sun) && !defined(B43) && !defined(ISC) && !defined(pyr) && !defined(_CX_UX)
-# include <time.h>
-#endif
-#include <sys/time.h>
 #ifndef sun
 #include <sys/ioctl.h>
 #endif
@@ -762,7 +758,7 @@ int key;
 
 	  if (plp->buf)
 	    free(plp->buf);
-	  plp->buf = SaveStr(expand_vars(args[1]));
+	  plp->buf = SaveStr(args[1]);
 	  plp->len = strlen(plp->buf);
 	}
       break;
@@ -1060,7 +1056,7 @@ int key;
             if (*s == '.')
 	      fore->w_pasteptr = d_user->u_copybuffer;
             else
-	      fore->w_pasteptr = plop_tab[(int)(unsigned char)ch].buf;
+	      fore->w_pasteptr = plop_tab[(int)(unsigned char)*s].buf;
 	    fore->w_pastelen = l;
 	    break;
           }
@@ -2497,6 +2493,11 @@ char *fn, **av;
   termbuf[0] = '\0';
   while (av && *av && av[0][0] == '-')
     {
+      if (av[0][1] == '-')
+	{
+	  av++;
+	  break;
+	}
       switch (av[0][1])
 	{
 	case 'f':
