@@ -21,7 +21,7 @@
  */
 
 #include "rcs.h"
-RCS_ID("$Id: pty.c,v 1.3 1993/08/04 00:42:48 mlschroe Exp $ FAU")
+RCS_ID("$Id: pty.c,v 1.4 1993/08/16 14:49:19 mlschroe Exp $ FAU")
 
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -45,6 +45,10 @@ RCS_ID("$Id: pty.c,v 1.3 1993/08/04 00:42:48 mlschroe Exp $ FAU")
 # include <sys/pty.h>
 #endif
 
+#ifdef sgi
+# include <sys/sysmacros.h>
+#endif /* sgi */
+
 #include "extern.h"
 
 /*
@@ -104,7 +108,7 @@ char **ttyn;
 }
 
 #else
-# ifdef MIPS
+# if defined(MIPS) && defined(HAVE_DEV_PTC)
 #  ifdef __sgi /* __sgi -> IRIX 4.0 */
 
 int
@@ -206,7 +210,7 @@ char **ttyn;
 }
 
 #  else /* not SVR4 */
-#   ifdef _AIX /* RS6000 */
+#   if defined(_AIX) && defined(HAVE_DEV_PTC) /* RS6000 */
 
 int
 OpenPTY(ttyn)
