@@ -23,7 +23,6 @@
 #include "rcs.h"
 RCS_ID("$Id: resize.c,v 1.3 1993/08/04 00:42:51 mlschroe Exp $ FAU")
 
-#include <stdio.h>
 #include <sys/types.h>
 #include <signal.h>
 #ifndef sun
@@ -579,7 +578,7 @@ nomem:	  KillWindow(p);
   p->w_top = 0;
   p->w_bot = he - 1;
 #ifdef TIOCSWINSZ
-  if (p->w_ptyfd && p->w_pid)
+  if (p->w_ptyfd >= 0 && p->w_pid)
     {
       glwz.ws_col = wi;
       glwz.ws_row = he;
