@@ -21,21 +21,17 @@
  */
 
 #include "rcs.h"
-RCS_ID("$Id: screen.c,v 1.15 1993/08/05 14:24:06 mlschroe Exp $ FAU")
+RCS_ID("$Id: screen.c,v 1.17 1993/08/19 12:05:38 jnweiger Exp $ FAU")
 
 
+#include <sys/types.h>
 #include <ctype.h>
-#ifdef __sgi
-# include <stdio.h> /* needed before pwd.h to avoid ansi compiler whining */
-#endif /* __sgi */
 
-#include <pwd.h>
 #include <fcntl.h>
 #ifdef sgi
 # include <sys/sysmacros.h>
 #endif /* sgi */
 
-#include <sys/types.h>
 #ifdef ISC
 # include <sys/bsdtypes.h>
 #endif
@@ -51,10 +47,6 @@ RCS_ID("$Id: screen.c,v 1.15 1993/08/05 14:24:06 mlschroe Exp $ FAU")
 
 #include "config.h"
 
-#ifdef SHADOWPW
-# include <shadow.h>
-#endif /* SHADOWPW */
-
 #ifdef SVR4
 # include <sys/stropts.h>
 #endif
@@ -77,6 +69,11 @@ RCS_ID("$Id: screen.c,v 1.15 1993/08/05 14:24:06 mlschroe Exp $ FAU")
 
 #include "patchlevel.h"
 
+#include <pwd.h>
+#ifdef SHADOWPW
+# include <shadow.h>
+#endif /* SHADOWPW */
+
 
 #ifdef DEBUG
 FILE *dfp;
@@ -115,6 +112,7 @@ static sig_t SigChld __P(SIGPROTOARG);
 static sig_t SigInt __P(SIGPROTOARG);
 static sig_t CoreDump __P((int));
 static void  DoWait __P((void));
+static void  WindowDied __P((struct win *));
 
 
 #ifdef PASSWORD
@@ -444,6 +442,12 @@ char **av;
       ap = *++av;
       if (--ac > 0 && *ap == '-')
 	{
+	  if (ap[1] == '-' && ap[2] == 0)
+	    {
+	      av++;
+	      ac--;
+	      break;
+	    }
 	  switch (ap[1])
 	    {
 	    case 'a':
@@ -1352,6 +1356,7 @@ char **av;
 			{
 			  if (p->w_pastebuf)
 			    free(p->w_pastebuf);
+			  p->w_pastebuf = 0;
 			  p->w_pasteptr = 0;
 			  pastefd = -1;
 			}
@@ -1583,15 +1588,7 @@ char **av;
 			continue;
 #endif
 		      debug2("Window %d: read error (errno %d) - killing window\n", p->w_number, len ? errno : 0);
-		      if (ZombieKey)
-			{
-			  debug3("window %d (%s) going into zombie state fd %d",
-				 p->w_number, p->w_title, p->w_ptyfd);
-			  p->w_ptyfd = -1;
-			  debug("changed to -1\n");
-			}
-		      else
-		        KillWindow(p);
+		      WindowDied(p);
 		      nsel = 0;	/* KillWindow may change window order */
 		      break;	/* so we just break */
 		    }
@@ -1675,6 +1672,37 @@ char **av;
   /* NOTREACHED */
 }
 
+static void
+WindowDied(p)
+struct win *p;
+{
+  if (ZombieKey)
+    {
+      char buf[100];
+      struct tm *tp;
+      time_t now;
+
+      (void) time(&now);
+      tp = localtime(&now);
+      debug3("window %d (%s) going into zombie state fd %d",
+	     p->w_number, p->w_title, p->w_ptyfd);
+#ifdef UTMPOK
+      RemoveUtmp(p);
+#endif
+      (void) chmod(p->w_tty, 0666);
+      (void) chown(p->w_tty, 0, 0);
+      close(p->w_ptyfd);
+      p->w_ptyfd = -1;
+      p->w_pid = 0;
+      ResetWindow(p);
+      p->w_y = p->w_bot;
+      sprintf(buf, "\n=== Window terminated at %2d:%02d:%02d ===", tp->tm_hour, tp->tm_min, tp->tm_sec);
+      WriteString(p, buf, strlen(buf));
+    }
+  else
+    KillWindow(p);
+}
+
 static void
 SigChldHandler()
 {
@@ -1864,15 +1892,7 @@ DoWait()
 	      else
 #endif
 		{
-		  if (ZombieKey)
-		    {
-		      debug3("window %d (%s) going into zombie state fd %d",
-		             p->w_number, p->w_title, p->w_ptyfd);
-		      p->w_ptyfd = -1;
-		      debug("changed to -1\n");
-		    }
-		  else
-		    KillWindow(p);
+		  WindowDied(p);
 		}
 	      break;
 	    }
