@@ -252,5 +252,3 @@ struct plop
   int len;
 };
 
-#define PRSTART '['
-#define PREND ']'
