@@ -21,7 +21,7 @@
  */
 
 #include "rcs.h"
-RCS_ID("$Id: socket.c,v 1.11 1993/08/04 00:43:00 mlschroe Exp $ FAU")
+RCS_ID("$Id: socket.c,v 1.16 1993/08/16 17:02:22 jnweiger Exp $ FAU")
 
 #include "config.h"
 #include <sys/types.h>
@@ -37,9 +37,9 @@ RCS_ID("$Id: socket.c,v 1.11 1993/08/04 00:43:00 mlschroe Exp $ FAU")
 #include <sys/un.h>
 #endif
 #include <signal.h>
-#ifndef M_XENIX
-#include <sys/time.h>
-#endif /* M_XENIX */
+
+#include "screen.h"
+
 #ifdef DIRENT
 # include <dirent.h>
 #else
@@ -47,16 +47,6 @@ RCS_ID("$Id: socket.c,v 1.11 1993/08/04 00:43:00 mlschroe Exp $ FAU")
 # define dirent direct
 #endif
 
-#include "screen.h"
-
-#ifdef USEVARARGS
-# if defined(__STDC__)
-#  include <stdarg.h>
-# else
-#  include <varargs.h>
-# endif
-#endif
-
 #include "extern.h"
 
 #if defined(_SEQUENT_) && !defined(NAMEDPIPE)
@@ -849,6 +839,33 @@ int pid;
   return UserStatus();
 }
 
+#ifdef hpux
+/*
+ * From: "F. K. Bruner" <napalm@ugcs.caltech.edu>
+ * From: "Dan Egnor" <egnor@oracorp.com> Tue Aug 10 06:56:45 1993
+ * The problem is that under HPUX (and possibly other systems too) there are
+ * two equivalent device files for each pty/tty device:
+ * /dev/ttyxx == /dev/pty/ttyxx
+ * /dev/ptyxx == /dev/ptym/ptyxx
+ * I didn't look into the exact specifics, but I've run across this problem
+ * before: Even if you open /dev/ttyxx as fds 0 1 & 2 for a process, if that
+ * process calls the system to determine its tty, it'll get /dev/pty/ttyxx.
+ *
+ * Earlier versions seemed to work -- wonder what they did.
+ */
+static int
+ttycmp(s1, s2)
+char *s1, *s2;
+{
+  if (strlen(s1) > 5) s1 += strlen(s1) - 5;
+  if (strlen(s2) > 5) s2 += strlen(s2) - 5;
+  return strcmp(s1, s2);
+}
+# define TTYCMP(a, b) ttycmp(a, b)
+#else
+# define TTYCMP(a, b) strcmp(a, b)
+#endif
+
 void
 ReceiveMsg()
 {
@@ -857,9 +874,7 @@ ReceiveMsg()
   char *p;
   int ns = ServerSocket;
   struct mode Mode;
-#ifdef UTMPOK
   struct win *wi;
-#endif
 #ifdef REMOTE_DETACH
   struct display *next;
 #endif
@@ -919,18 +934,17 @@ ReceiveMsg()
     }
   debug2("*** RecMsg: type %d tty %s\n", m.type, m.m_tty);
   for (display = displays; display; display = display->_d_next)
-    if (strcmp(d_usertty, m.m_tty) == 0)
+    if (TTYCMP(d_usertty, m.m_tty) == 0)
       break;
   debug2("display: %s display %sfound\n", m.m_tty, display ? "" : "not ");
   if (!display)
     {
-      struct win *w;
-
-      for (w = windows; w; w = w->w_next)
-        if (!strcmp(m.m_tty, w->w_tty))
+      for (wi = windows; wi; wi = wi->w_next)
+        if (!TTYCMP(m.m_tty, wi->w_tty))
 	  {
-            display = w->w_display;
-	    debug2("but window %s %sfound.\n", m.m_tty, display ? "" : "deatached (ignoring) ");
+            display = wi->w_display;
+	    debug2("but window %s %sfound.\n", m.m_tty, display ? "" : 
+	    	   "(backfacing)");
 	    break;
           }
     }
@@ -946,7 +960,15 @@ ReceiveMsg()
         CheckScreenSize(1); /* Change fore */
       break;
     case MSG_CREATE:
-      if (display)
+      /*
+       * the window that issued the create message need not be an active
+       * window. Then we create the window without having a display.
+       * Resulting in another inactive window.
+       * 
+       * Currently we enforce that at least one display exists. But why?
+       * jw.
+       */
+      if (displays)
 	ExecCreate(&m);
       break;
     case MSG_CONT:
@@ -1035,7 +1057,7 @@ ReceiveMsg()
 	  Kill(m.m.attach.apid, SIG_BYE);
 	  break;
         }
-#ifdef ultrix
+#if defined(ultrix) || defined(pyr)
       brktty(d_userfd);	/* for some strange reason this must be done */
 #endif
 #if defined(pyr) || defined(xelos) || defined(sequent)
