@@ -21,7 +21,7 @@
  */
 
 #include "rcs.h"
-RCS_ID("$Id: utmp.c,v 1.3 1993/07/21 15:43:38 mlschroe Exp $ FAU")
+RCS_ID("$Id: utmp.c,v 1.6 1993/08/05 14:24:12 mlschroe Exp $ FAU")
 
 
 /*
@@ -495,7 +495,7 @@ struct win *wi;
       strncpy(u.ut_line, line, sizeof(u.ut_line));
       u.ut_pid = wi->w_pid;
       u.ut_type = USER_PROCESS;
-      (void) time(&u.ut_time);
+      (void) time((time_t *)&u.ut_time);
     } /* !saved_ut {-: */
   setutent();
   if (pututline(&u) == 0)
@@ -507,7 +507,7 @@ struct win *wi;
       u.ut_pid = wi->w_pid;
       strncpy(u.ut_id, line + 3, sizeof(u.ut_id));
 #   endif /* linux */
-      (void) time(&u.ut_time);
+      (void) time((time_t *)&u.ut_time); /* cast needed for ultrix */
     } /* !saved_ut */
 #   ifdef sequent
   /*
@@ -539,6 +539,7 @@ struct win *wi;
 # ifdef UTNOKEEP
   close(utmpfd);
 # endif /* UTNOKEEP */
+  bcopy((char *) &u, (char *) &wi->w_savut, sizeof u);
   return 0;
 }
 
@@ -580,6 +581,10 @@ struct win *wi;
   bzero((char *) &u, sizeof u);
 # ifdef GETUTENT
   setutent();
+#  ifdef sgi
+  bcopy((char *) &wi->w_savut, (char *) &u, sizeof u);
+  uu  = &u;
+#  else
   strncpy(u.ut_line, slot, sizeof(u.ut_line));
   if ((uu = getutline(&u)) == 0)
     {
@@ -587,6 +592,7 @@ struct win *wi;
       return -1;
     }
   bcopy((char *)uu, (char *)&wi->w_savut, sizeof(wi->w_savut));
+#  endif
 #  ifdef _SEQUENT_
   if (ut_delete_user(slot, uu->ut_pid, 0, 0) == 0)
 #  else /* _SEQUENT_ */
