@@ -21,7 +21,7 @@
  */
 
 #include "rcs.h"
-RCS_ID("$Id: window.c,v 1.14 1993/08/05 14:24:15 mlschroe Exp $ FAU")
+RCS_ID("$Id: window.c,v 1.15 1993/08/16 14:49:32 mlschroe Exp $ FAU")
 
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -256,9 +256,13 @@ struct win *wp;
 #ifdef UTMPOK
   RemoveUtmp(wp);
 #endif
-  (void) chmod(wp->w_tty, 0666);
-  (void) chown(wp->w_tty, 0, 0);
-  close(wp->w_ptyfd);
+  if (wp->w_ptyfd >= 0)
+    {
+      (void) chmod(wp->w_tty, 0666);
+      (void) chown(wp->w_tty, 0, 0);
+      close(wp->w_ptyfd);
+      wp->w_ptyfd = -1;
+    }
   if (wp == console_window)
     console_window = 0;
   if (wp->w_logfp != NULL)
