@@ -18,7 +18,7 @@
  * Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
  ****************************************************************
- * $Id: window.h,v 1.6 1993/07/21 15:43:44 mlschroe Exp $ FAU
+ * $Id: window.h,v 1.9 1993/08/05 14:24:19 mlschroe Exp $ FAU
  */
 
 #ifndef MAXWIN
@@ -99,7 +99,7 @@ struct win
   int	 w_inlen;
   char	 w_outbuf[IOSIZE];
   int	 w_outlen;
-  char  *w_aka;			/* name of the window */
+  char  *w_title;		/* name of the window */
   char  *w_akachange;		/* autoaka hack */
   int	 w_autoaka;		/* autoaka hack */
   char	 w_akabuf[MAXSTR];	/* aka buffer */
@@ -134,7 +134,8 @@ struct win
   int	 w_keypad;		/* keypad mode */
   int	 w_cursorkeys;		/* appl. cursorkeys mode */
 #ifdef COPY_PASTE
-  char	*w_pastebuffer;		/* this gets pasted in the window */
+  char	*w_pastebuf;		/* this gets pasted in the window */
+  char	*w_pasteptr;		/* pointer in pastebuf */
   int	 w_pastelen;		/* bytes left to paste */
   int	 w_histheight;		/* all histbases are malloced with width * histheight */
   int	 w_histidx;		/* 0 <= histidx < histheight; where we insert lines */
